@@ -14,15 +14,23 @@ module Reflex.Vty
   ( module Reflex
   , module Reflex.Vty.Host
   , module Reflex.Vty.Widget
+  , module Reflex.Vty.Widget.Box
   , module Reflex.Vty.Widget.Input
   , module Reflex.Vty.Widget.Layout
+  , module Reflex.Vty.Widget.Scroll
+  , module Reflex.Vty.Widget.Split
+  , module Reflex.Vty.Widget.Text
   , module Control.Monad.NodeId
   ) where
 
 import Reflex
 import Reflex.Vty.Host
 import Reflex.Vty.Widget
+import Reflex.Vty.Widget.Box
 import Reflex.Vty.Widget.Input
 import Reflex.Vty.Widget.Layout
+import Reflex.Vty.Widget.Scroll
+import Reflex.Vty.Widget.Split
+import Reflex.Vty.Widget.Text
 
 import Control.Monad.NodeId
